from Crypto.Hash import SHA256
from commons import *
import requests

class Client(object):
    """
    Client contains all the basic functions of a client perspective
    of an IBE scheme. Client will have its own Secret Key and the PKG
    Master Public Key. This way it can calculate any Public Key, 
    including its own.
    """
    
    def __init__(self, identity, pkg_url):
        self.identity = identity
        self.pkg_url = pkg_url
        self.pkg_public_key = requests.get(self.pkg_url + '/public_key/').text

        self.public_key = gen_public_key(self.identity, self.pkg_public_key)
        #TODO authenticate with server 
        self.private_key = requests.get(self.pkg_url + '/extract_key/' + self.identity).text

if __name__ == '__main__':
    client = Client('foo@example.com', 'http://localhost:5000')
    print(client.public_key)
    print(client.private_key)



from Crypto.Hash import SHA256

def gen_public_key(identity, pkg_public_key):
    """
    Returns the public key of an individual using the PKG Public Key
    If there are multiple PKGs, the pkg_public_key must be the
    same that the individual used to generate its own Private Key.
    """
    h = SHA256.new()
    h.update(identity.encode('utf-8'))
    h.update(pkg_public_key.encode('utf-8'))
    return h.hexdigest()

def encrypt(public_key, message):
    """
    Encrypts the especified message with a Random Session Key (RSK).
    The RSK is then encrypted with the individual's public key and 
    added to the encrypted text.
    """
    pass

def encrypt(identity, pkg_public_key, message):
    """
    Equivalent to encrypt(public_key, message) but will generate the
    individual's public key before calling encrypt.
    """
    public_key = make_public_key(identity, pkg_public_key)
    return encrypt(public_key, message)

def decrypt(secret_key, message):
    """
    Decrypts the message using the individual's Secret Key
    """
    pass




from distutils.core import setup

setup(
    name='Ibe',
    version='0.1.0',
    author='Lucas Pandolfo Perin / Lucas Boppre Niehues',
    author_email='lucasperin@gmail.com / lucasboppre@gmail.com',
    packages=['ibe'],
    url='http://pypi.python.org/pypi/Ibe/',
    license='LICENSE.txt',
    description='Simple IBE library - This might be the start of something really neat!',
    long_description=open('README.rst').read(),
    
    scripts=['bin/pkg_server.py','bin/install_pypbc.sh'],
    install_requires=[
        "crypto",
    ],
)